# frozen_string_literal: true

require 'obfuscated_morse_code/version'
require 'obfuscated_morse_code/file_parser'
require 'obfuscated_morse_code/morse_code_translator'
require 'obfuscated_morse_code/morse_code_obfuscator'

module ObfuscatedMorseCode
  def self.morse_code(file_path)
    parsed_text = FileParser.new(file_path).parse
    MorseCodeTranslator.new.translate(parsed_text).join("\n")
  rescue ArgumentError => e
    puts e.message
  rescue FileParser::FileNotFoundError => e
    puts e.message
  end

  def self.obfuscated_morse_code(file_path)
    parsed_text = FileParser.new(file_path).parse
    morse_code = MorseCodeTranslator.new.translate(parsed_text)
    MorseCodeObfuscator.new(morse_code).obfuscate.join("\n")
  rescue ArgumentError => e
    puts e.message
  rescue FileParser::FileNotFoundError => e
    puts e.message
  end
end
