# frozen_string_literal: true

module ObfuscatedMorseCode
  class MorseCodeObfuscator
    DASH_OBFUSCATION_DICTIONARY = %w[A B C D E].freeze

    attr_reader :morse_codes

    def initialize(morse_codes)
      @morse_codes = morse_codes
    end

    def obfuscate
      morse_codes.map do |code|
        obfuscated = replace_dots_with_numbers(code)
        replace_dashes_with_characters(obfuscated)
      end
    end

    private

    def replace_dots_with_numbers(code)
      obfuscated_code = ''
      number_of_dots_found = 0
      code.split('').each do |character|
        if character == '.'
          number_of_dots_found += 1
        else
          if number_of_dots_found.positive?
            obfuscated_code += number_of_dots_found.to_s
          end
          obfuscated_code += character
          number_of_dots_found = 0
        end
      end
      obfuscated_code += number_of_dots_found.to_s if number_of_dots_found.positive?
      obfuscated_code
    end

    def replace_dashes_with_characters(code)
      obfuscated_code = ''
      number_of_dashes_found = 0
      code.split('').each do |character|
        if character == '-'
          number_of_dashes_found += 1
        else
          if number_of_dashes_found.positive?
            obfuscated_code += DASH_OBFUSCATION_DICTIONARY[number_of_dashes_found - 1]
          end
          obfuscated_code += character
          number_of_dashes_found = 0
        end
      end
      obfuscated_code += DASH_OBFUSCATION_DICTIONARY[number_of_dashes_found - 1] if number_of_dashes_found.positive?
      obfuscated_code
    end
  end
end
