# frozen_string_literal: true

require 'obfuscated_morse_code/dictionary'

module ObfuscatedMorseCode
  class MorseCodeTranslator
    attr_reader :letter_separator, :word_separator

    def initialize(letter_separator: '|', word_separator: '/')
      @letter_separator = letter_separator
      @word_separator = word_separator
    end

    def translate(sentences)
      sentences.map do |sentence|
        letters = sentence.split('')
        translate_letters(letters)
      end
    end

    private

    def translate_letters(letters)
      translated_letters = ''
      letters.each_with_index do |letter, i|
        next_letter = letters[i + 1]
        translated_letters += translate_letter(letter)
        unless letter == ' '
          translated_letters += word_separator_for(next_letter)
        end
      end
      translated_letters
    end

    def translate_letter(letter)
      return '' if letter == ' '
      raise ArgumentError, "cannot translate character #{letter}" unless MORSE_CODE.key?(letter)

      MORSE_CODE[letter]
    end

    def word_separator_for(next_letter)
      return word_separator if next_letter == ' '
      return '' if next_letter.nil?

      letter_separator
    end
  end
end
